==> tdesvn-trinity-14.0.8.tar.xz: tdesvn-trinity-14.0.8/src/svnfrontend/fronthelpers/rangeinput_impl.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef RANGEINPUT_IMPL_H
#define RANGEINPUT_IMPL_H

#include "rangeinput.h"
#include "revision.hpp"
#include <tqpair.h>

class Rangeinput_impl: public RangeInputDlg {
Q_OBJECT
  
public:
    Rangeinput_impl(TQWidget *parent = 0, const char *name = 0);
    virtual ~Rangeinput_impl();

    typedef TQPair<svn::Revision,svn::Revision> revision_range;

    revision_range getRange();

    virtual void setStartOnly(bool theValue);
    virtual void setNoWorking(bool aValue);


    bool StartOnly() const;
    void setHeadDefault();

protected slots:
    virtual void onHelp();
    virtual void stopHeadToggled(bool);
    virtual void stopBaseToggled(bool);
    virtual void stopNumberToggled(bool);
    virtual void startHeadToggled(bool);
    virtual void startBaseToggled(bool);
    virtual void startNumberToggled(bool);
    virtual void stopDateToggled(bool);
    virtual void startDateToggled(bool);
protected:
    bool m_StartOnly;
};

#endif

==> tdesvn-trinity-14.0.13.tar.xz: tdesvn-trinity-14.0.13/src/svnfrontend/fronthelpers/rangeinput_impl.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef RANGEINPUT_IMPL_H
#define RANGEINPUT_IMPL_H

#include "rangeinput.h"
#include "revision.h"
#include <tqpair.h>

class Rangeinput_impl: public RangeInputDlg {
Q_OBJECT
  
public:
    Rangeinput_impl(TQWidget *parent = 0, const char *name = 0);
    virtual ~Rangeinput_impl();

    typedef TQPair<svn::Revision,svn::Revision> revision_range;

    revision_range getRange();

    virtual void setStartOnly(bool theValue);
    virtual void setNoWorking(bool aValue);


    bool StartOnly() const;
    void setHeadDefault();

protected slots:
    virtual void onHelp();
    virtual void stopHeadToggled(bool);
    virtual void stopBaseToggled(bool);
    virtual void stopNumberToggled(bool);
    virtual void startHeadToggled(bool);
    virtual void startBaseToggled(bool);
    virtual void startNumberToggled(bool);
    virtual void stopDateToggled(bool);
    virtual void startDateToggled(bool);
protected:
    bool m_StartOnly;
};

#endif
